@@ -10,7 +10,7 @@ use Scalar::Util 'weaken';
 
 has accepts            => 10000;
 has cleanup            => 1;
-has graceful_timeout   => 60;
+has graceful_timeout   => 120;
 has heartbeat_timeout  => 30;
 has heartbeat_interval => 5;
 has pid_file           => sub { path(tmpdir, 'prefork.pid')->to_string };
@@ -155,7 +155,7 @@ sub _spawn {
   # Clean worker environment
   $SIG{$_} = 'DEFAULT' for qw(CHLD INT TERM TTIN TTOU);
   $SIG{QUIT} = sub { $loop->stop_gracefully };
-  $loop->on(finish => sub { $self->max_requests(1)->close_idle_connections });
+  $loop->on(finish => sub { $self->max_requests(1) });
   delete $self->{reader};
   srand;
 
@@ -315,7 +315,7 @@ Emitted when a heartbeat message has been received from a worker.
     ...
   });
 
-Emitted when a child process dies.
+Emitted when a child process exited.
 
   $prefork->on(reap => sub {
     my ($prefork, $pid) = @_;
@@ -382,8 +382,9 @@ a true value.
   $prefork    = $prefork->graceful_timeout(15);
 
 Maximum amount of time in seconds stopping a worker gracefully may take before
-being forced, defaults to C<60>. Note that this value should usually be a little
-larger than the maximum amount of time you expect any one request to take.
+being forced, defaults to C<120>. Note that this value should usually be a
+little larger than the maximum amount of time you expect any one request to
+take.
 
 =head2 heartbeat_interval
 
@@ -464,6 +465,6 @@ Run server and wait for L</"MANAGER SIGNALS">.
 
 =head1 SEE ALSO
 
-L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
+L<Mojolicious>, L<Mojolicious::Guides>, L<https://mojolicious.org>.
 
 =cut
