@@ -5,13 +5,11 @@ use Mojo::Asset::File;
 use Mojo::Asset::Memory;
 use Mojo::Date;
 use Mojo::File 'path';
-use Mojo::Home;
 use Mojo::Loader qw(data_section file_is_binary);
 use Mojo::Util qw(encode md5_sum trim);
 
 # Bundled files
-my $PUBLIC = Mojo::Home->new(Mojo::Home->new->mojo_lib_dir)
-  ->child('Mojolicious', 'resources', 'public');
+my $PUBLIC = path(__FILE__)->sibling('resources', 'public');
 my %EXTRA = $PUBLIC->list_tree->map(
   sub { join('/', @{$_->to_rel($PUBLIC)}), $_->realpath->to_string })->each;
 
